timesignaturetools.make_gridded_test_rhythm
===========================================

.. autofunction:: abjad.tools.timesignaturetools.make_gridded_test_rhythm.make_gridded_test_rhythm
   :noindex:
